.. include:: ../README.md
   :parser: myst_parser.sphinx_
   :start-after: <!-- index.rst content start -->


API Reference
-------------

.. toctree::
   :maxdepth: 2
   :caption: API Reference:

   api
